/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: Internal                                         *
*                                                                    *
*       Current version number will be inserted here                 *
*       when shipment is built.                                      *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : Provides mapping of altera event flag functions to
          embOS functions
*/

#ifndef __ALT_FLAG_EMBOS_H__
#define __ALT_FLAG_EMBOS_H__

#include "RTOS.h"

#ifdef __cplusplus
extern "C"
{
#endif

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       alt_flag_create()
*
*  Function description:
*    alt_flag_create() is a wrapper for OS_EVENT_Create()
*    it does not return any error
*/
static ALT_INLINE int ALT_ALWAYS_INLINE alt_flag_create (OS_EVENT* pEvent) {
  OS_EVENT_Create(pEvent);
  return 0;
}

/*********************************************************************
*
*       alt_flag_pend()
*
*  Function description:
*    alt_flag_pend() is a wrapper for OS_EVENT_GetTimed() or OS_EVENT_GetBlocked(),
*    with the error code converted into the functions return value.
*    The event will always be consumed.
*/
static ALT_INLINE int ALT_ALWAYS_INLINE alt_flag_pend (OS_EVENT* pEvent, int timeout) {
  if (timeout == 0) {
    OS_EVENT_GetBlocked(pEvent);
  } else {
    OS_EVENT_GetTimed(pEvent, timeout);
  }
  return 0;
}

/*********************************************************************
*
*       alt_flag_post()
*
*  Function description:
*    alt_flag_post() is a wrapper for OS_EVENT_Set(),
*    which returns with no error
*/
static ALT_INLINE int ALT_ALWAYS_INLINE alt_flag_post (OS_EVENT* pEvent) {
  OS_EVENT_Set(pEvent);
  return 0;
}

#ifdef __cplusplus
}
#endif

#endif  // __ALT_FLAG_EMBOS_H__

/*************************** End of file ****************************/
