/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: Internal                                         *
*                                                                    *
*       Current version number will be inserted here                 *
*       when shipment is built.                                      *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : Defines functions for semaphore handling of embOS
          which are called by NIOS system library and HAL.
          These functions are used to map the HAL API to embOS API.
*/

#ifndef __ALT_SEM_EMBOS_H__
#define __ALT_SEM_EMBOS_H__

#include "RTOS.h"

#ifdef __cplusplus
extern "C"
{
#endif

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       alt_sem_create()
*
*  Function decription:
*    This function is called to create a semaphore.
*    It is a wrapper for OS_SEMAPHORE_Create().
*
*  Return value:
*    0 on success
*    The return value is always 0, because semaphore creation is always
*    successful using embOS
*/
static ALT_INLINE int ALT_ALWAYS_INLINE alt_sem_create (OS_SEMAPHORE* sem, OS_U16 value) {
  OS_SEMAPHORE_Create(sem, value);
  return 0;
}

/*********************************************************************
*
*       alt_sem_pend()
*
*  Function decription:
*    Waits for a semaphore to become available.
*    May be used with timeout.
*
*  Return value:
*    0: success
*    otherwise timeout
*/
static ALT_INLINE int ALT_ALWAYS_INLINE alt_sem_pend (OS_SEMAPHORE* sem, OS_U16 timeout) {
  if (timeout == 0) {  /* No timeout, wait until semaphore is available */
    OS_SEMAPHORE_TakeBlocked(sem);
    return 0;
  } else {
    return OS_SEMAPHORE_TakeTimed(sem, timeout) ? 0 : 1;
  }
}

#ifdef __cplusplus
}
#endif

#endif  // __ALT_SEM_EMBOS_H__

/*************************** End of file ****************************/
