/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: Internal                                         *
*                                                                    *
*       Current version number will be inserted here                 *
*       when shipment is built.                                      *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : Defines hook functions needed for embOS system timer and
          interrupt locking.
          These functions are required and called by NIOS_HAL
*/

#ifndef __ALT_HOOKS_H__
#define __ALT_HOOKS_H__

#ifndef ALT_ASM_SRC

#include "RTOS.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define ALT_OS_TIME_TICK()  OS_ISR_Tick()
#define ALT_OS_INIT()       OS_Init()
#define ALT_OS_STOP()       while(0)
#define ALT_OS_INT_ENTER()  OS_INT_Enter()
#define ALT_OS_INT_EXIT()   OS_INT_Leave()

#endif

#ifndef ALTERA_VIC_DRIVER_PREEMPTION_INTO_NEW_REGISTER_SET_ENABLED
  //
  // Standard interrupts with VIC are not nestable
  //
  #define ALT_OS_INT_ENTER_ASM    call OS_EnterInterruptASM
  #define ALT_OS_INT_EXIT_ASM     call OS_LeaveInterruptASM
#else
  //
  // Nested interrupts with VIC, enabled by project options, require modified functions
  //
  #define ALT_OS_INT_ENTER_ASM    call OS_EnterNestableInterruptASM
  #define ALT_OS_INT_EXIT_ASM     call OS_LeaveNestableInterruptASM
#endif

#endif

/*************************** End of file ****************************/
