/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: Internal                                         *
*                                                                    *
*       Current version number will be inserted here                 *
*       when shipment is built.                                      *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : CPU and compiler specifics for XXX and XXX
          OS internal
*/

#ifndef OS_PRIVATE_H                    /* Avoid multiple inclusion */
#define OS_PRIVATE_H

/*********************************************************************
*
*       CPU and Library Name
*
**********************************************************************
*/
#define OS_CPU                    "NIOS_II/GNU"
#define OS_PORT_VERSION           50820                  // Version number of tested version
#define OS_VALUE_2PTR(x)          ((int)x)               // Avoid compiler warning
#define OS_DATA_MEMORY_BARRIER()  __sync_synchronize();  // GCC built-in function to issue a full memory barrier

/*********************************************************************
*
*       Prototypes
*
**********************************************************************
*/
#ifdef __cplusplus
  extern "C" {
#endif
void OS_EnterInterruptASM        (void);
void OS_LeaveInterruptASM        (void);
void OS_EnterNestableInterruptASM(void);
void OS_LeaveNestableInterruptASM(void);
void OS_SwitchFromIntASM         (void);
#ifdef __cplusplus
  }
#endif

/*********************************************************************
*
*       Register structure, Chip specifics
*
**********************************************************************
*/
typedef struct {
  OS_REGS_BASE Regs;
  OS_U32       PC_Task;
} OS_REGS_INIT;

/*********************************************************************
*
*       Register initialization, called from OS_TASK_Create()
*/
#if (OS_DEBUG != 0)
  #define OS_INITREGS_DEBUG()                                 \
     ((OS_REGS_INIT*)pStack)->Regs.OS_REG_R16 = 0xCCCC0016u;  \
     ((OS_REGS_INIT*)pStack)->Regs.OS_REG_R17 = 0xCCCC0017u;  \
     ((OS_REGS_INIT*)pStack)->Regs.OS_REG_R18 = 0xCCCC0018u;  \
     ((OS_REGS_INIT*)pStack)->Regs.OS_REG_R19 = 0xCCCC0019u;  \
     ((OS_REGS_INIT*)pStack)->Regs.OS_REG_R20 = 0xCCCC0020u;  \
     ((OS_REGS_INIT*)pStack)->Regs.OS_REG_R21 = 0xCCCC0021u;  \
     ((OS_REGS_INIT*)pStack)->Regs.OS_REG_R22 = 0xCCCC0022u;  \
     ((OS_REGS_INIT*)pStack)->Regs.OS_REG_R23 = 0xCCCC0023u;
#else
  #define OS_INITREGS_DEBUG()
#endif

#define OS_INITREGS()                                                               \
   {                                                                                \
   pStack                                   = (char*) ((int) pStack & 0xFFFFFFFCu); \
   ((OS_REGS_INIT*)pStack)->Regs.Counters   = 0u;                                   \
   ((OS_REGS_INIT*)pStack)->Regs.OS_REG_PC  = (OS_U32)OS_StartTask;                 \
   ((OS_REGS_INIT*)pStack)->PC_Task         = (OS_U32)pRoutine;                     \
   OS_INITREGS_DEBUG();                                                             \
   }

/*********************************************************************
*
*       Register initialization, called from OS_TASK_CreateEx()
*       OS_StartTask() (in assembly part) has to copy the value from R4
*       into R0 to pass it as parameter to the task
*/
#define OS_INITREGS_EX(pContext) OS_INITREGS()                 \
   ((OS_REGS_INIT*)pStack)->Regs.OS_REG_R16 = (int)(pContext);

#endif                                // Avoid multiple inclusion

/*************************** End of file ****************************/

