/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: Internal                                         *
*                                                                    *
*       Current version number will be inserted here                 *
*       when shipment is built.                                      *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : Provides embOS thread safe locking of environment variables
*/

#include <reent.h>
#include "RTOS.h"

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static OS_MUTEX OS_EnvSema;
static char     _IsInited;

/*********************************************************************
*
*       __env_lock()
*/
void __env_lock ( struct _reent *_r ) {
  OS_TASK_EnterRegion();
  if (!_IsInited) {
    OS_MUTEX_Create(&OS_EnvSema);
    _IsInited = 1;
  }
  OS_TASK_LeaveRegion();
  OS_MUTEX_LockBlocked(&OS_EnvSema);
}

/*********************************************************************
*
*       __env_unlock()
*/
void __env_unlock ( struct _reent *_r ) {
  OS_MUTEX_Unlock(&OS_EnvSema);
}

/*************************** End of file ****************************/
